<?php

	class ClientsController extends AppController {

	    public $helpers = array('Html', 'Form');

	    public $uses = array('Client', 'Setting');

	    public function beforeFilter() {
	        $this->set('title', 'clients');

	        // Block Clients From Entire Dashboard & Redirect Them To Their Client Area
	        // Allow Clients Access To Own Area client_area()

	        $role = parent::roleCheck();
        	
        	if ($role === 'client') {

        		if ($this->action !== 'client_area') {

	        		$clientName = $this->Auth->user('first_name');

	        		$client = $this->Client->find('first', array(
	        			'conditions' => array('Client.client_name' => $clientName),
				        'fields' => array('id'),
					    'recursive' => 0
				    ));

	        		$this->Session->setFlash('Clients Are Only Authorised To View Their Own Area');

	        		$this->redirect(array('controller' => 'clients', 'action' => 'client_area', $client['Client']['id']));

	        	}

        	} 

	    }


	    function index() {

	        $this->set('clients', $this->Client->find('all'));

	    }



	    public function view($id = null) {
	        if (!$id) {
	            throw new NotFoundException(__('Invalid Client'));
	        }

	        $client = $this->Client->findById($id);
	        if (!$client) {
	            throw new NotFoundException(__('Invalid Client'));
	        }

	        $settings = $this->Setting->find('first', array(
		        'fields' => array('currency', 'primary_color'),
			    'recursive' => 0
		    ));


	        $this->set('thisClient', $client);
	        $this->set('settings', $settings);
	    }





	    function add() {

	    	if ($this->request->is('post')) {

	            $this->Client->create();

	            if ($this->Client->save($this->request->data)) {

	                $this->Session->setFlash('Client Successfully Added');

	                $client_name = $this->request->data['Client']['client_name'];

	                $client = $this->Client->findByClientName($client_name);

	                $id = $client['Client']['id'];

	                $this->redirect(array('controller' => 'clients', 'action' => 'view', $id));

	            } else {

	                $this->Session->setFlash('Unable To Add Client');

	            }

	        }

	    }


	    function edit($id = NULL) {

	        if (!$id) {

		        throw new NotFoundException(__('Invalid Client'));

		    }

		    $client = $this->Client->findById($id);

		    if (!$client) {

		        throw new NotFoundException(__('Invalid Client'));

		    }

		    if ($this->request->is('post') || $this->request->is('put')) {

		        $this->Client->id = $id;

		        if ($this->Client->save($this->request->data)) {

		            $this->Session->setFlash('Your Client Has Been Updated');

		            $this->redirect(array('controller' => 'clients', 'action' => 'view', $id));

		        } else {

		            $this->Session->setFlash('Unable To Update Your Client');

		        }

		    }

		    if (!$this->request->data) {

		        $this->request->data = $client;

		    }

	    }


	    function delete($id) {

		    if ($this->request->is('get')) {

		        throw new MethodNotAllowedException('MY NEW GET ERROR');

		    }

		    if ($this->Client->delete($id)) {

		        $this->Session->setFlash('The Client Has Been Deleted.');

		        $this->redirect(array('action' => 'index'));

		    }
		}



		public function get_names() {
	        if (empty($this->request->params['requested'])) {
	            throw new ForbiddenException();
	        }

	        return $this->Client->find('all', array(
	        	'order' => array('Client.client_name' => 'asc'),
		        'fields' => array('Client.client_name', 'Client.id'),
		        'recursive' => 0,
		    ));

	        //return $this->Client->find('all');
	    }


	    public function client_area($id = null) {
	        if (!$id) {
	            throw new NotFoundException(__('Invalid Client'));
	        }

	        $client = $this->Client->findById($id);
	        if (!$client) {
	            throw new NotFoundException(__('Invalid Client'));
	        }

	        // Block Clients From Accessing Other Client's Area

	        if ($client['Client']['client_name'] !== AuthComponent::user('first_name')) {

				$this->Session->setFlash('Clients Are Only Authorised To View Their Own Area');

	        	$this->redirect(array('controller' => 'dashboard', 'action' => 'index'));

	        }

	        $this->layout = 'client';

	        $settings = $this->Setting->find('first', array(
		        'fields' => array('currency', 'primary_color'),
			    'recursive' => 0
		    ));


	        $this->set('thisClient', $client);
	        $this->set('settings', $settings);
	    }
	    



	}

?>