<?php echo $this->Html->script('prettify/prettify'); ?>

<?php echo $this->Html->css('prettify'); ?>

<h3>Welcome To Adaptive Client Manager</h3>

<p>Thank you for purchasing Adaptive Client Manager.</p>

<p>To get started, we first need to connect to your MySQL database. Please enter your database connection details below. If you are not sure of these settings, please consult the Adaptive Client Manager documentation and/or please contact your webhosting service provider.</p>


<?php if (SETUP_DISABLED == "NO") : ?>

<!-- STEP 1: Database Settings -->

<?php echo $this->Html->div('info_button_primary show_hide_button', '<span class="icon-star "></span>Step 1 : Database Settings');?>

<div class="report_form">

	<h5>Step 1: Database Settings</h5>

	<p><span class="bold">Note: </span>You may have already completed this step before you uploaded the files to your website if you followed the documentation. If that is the case, then you can skip to Step 2.</p>

	<p>In order to connect to the database, we need to tell Adaptive Client Manager how to connect to your database. To do this, simply open up the following file in any text editor:</p>

	<p class='bold'>adaptivecm/app/Config/database.php</p>

	<p>By default, it should look like this:</p>

	
	<pre class="prettyprint lang-php">
	class DATABASE_CONFIG {
		public $default = array(
			'datasource' => 'Database/Mysql',
			'persistent' => false,
			'host' => '<span class="bold">yourHost</span>', // Change To Your Own Host
			'login' => '<span class="bold">yourUsername</span>', // Change To Your Own Username
			'password' => '<span class="bold">yourPassword</span>', // Change To Your Own Password
			'database' => 'adaptivecm', // DO NOT CHANGE
			'prefix' => '',
		);
	}
	</pre>

	<p>There's no PHP knowledge needed to do this, just simply change the text highlighted in bold above for your own settings. For example, if your host is <span class="bold">myplace.db.106488.hostedresource.com</span>, your username is <span class="bold">captainJack</span> and your password is <span class="bold">topSecretPass</span>, you would change the file so it looks like this:</p>

	<pre class="prettyprint lang-php">
	class DATABASE_CONFIG {
		public $default = array(
			'datasource' => 'Database/Mysql',
			'persistent' => false,
			'host' => '<span class="bold">myplace.db.106488.hostedresource.com</span>', // Change To Your Own Host
			'login' => '<span class="bold">captainJack</span>', // Change To Your Own Username
			'password' => '<span class="bold">topSecretPass</span>', // Change To Your Own Password
			'database' => 'adaptivecm', // DO NOT CHANGE
			'prefix' => '',
		);
	}
	</pre>

	<p><span class="bold">Tip: </span>Be careful to leave the single quotation marks around each item you change in place</p>

	<p>That's all we need to do here...easy. Save the file and if you've already uploaded the files to your website, be sure to re-upload this file and overwrite the old one. You can refer to the Adaptive Client Manager documentation again if you need help with this.</p>

</div>

<!-- // END STEP 1 -->


<!-- STEP 2: Database Creation -->

<?php echo $this->Html->div('info_button_primary show_hide_button', '<span class="icon-star "></span>Step 2 : Database Creation');?>

<div class="report_form">

	<h5>Step 2: Database Creation</h5>

	<p>This next step is even easier. We're going to try to connect to your database and load in all the tables automatically so you don't have to. This works for most installations, however, it does depend on your host/settings.</p>

	<p>Enter the same settings (host, username and password) from Step 1 into the form below. Be sure to enter them carefully and <span class="bold">without</span> any single quotation (' ') marks this time.</p>

	<p>Once done, press the 'Save & Test Connection'. We'll attempt to connect to your database using those settings and, if successfull, we'll also try and install the database for you. If it installs successfully, you'll see a confirmation message that states 'The Installation Was Successfull'. If this happens, you can proceed to Step 3. </p>

	<p>If you don't get that message, and you get some error message, make a note of it, and then check out the Adaptive Client Manager documentation for assistance.</p>


	<?php echo $this->Form->create(null, array(
	    'url' => array('controller' => 'setup', 'action' => 'index')
	)); ?>


	<table>
		
		<tr>
			<th>Settings</th>
		</tr>

		<tr><td><?php echo $this->Form->input('database_host'); ?></td></tr>

		<tr><td><?php echo $this->Form->input('database_name'); ?></td></tr>

		<tr><td><?php echo $this->Form->input('database_username'); ?></td></tr>

		<tr><td>

			<?php echo $this->Form->input('database_password', array(
				'type' => 'password'
				));
			?>

		</td></tr>

	</table>

	<?php 
		echo $this->Form->input('id', array('type'=>'hidden'));
		echo $this->Form->end();
	?>

	<?php echo $this->Html->div('button_small', '<span class="icon-refresh"></span>Save & Test Connection', array('id' => 'test_connection_button'));?>

</div>

<!-- // END STEP 2 -->


<!-- STEP 3: Complete Setup -->

<?php echo $this->Html->div('info_button_primary show_hide_button', '<span class="icon-star "></span>Step 3 : Complete Setup');?>

<div class="report_form">

	<h5>Step 3: Complete Setup</h5>

	<p>Once installation has been successfull, use the 'Settings' link at the top to login using these default settings:</p>
	<p><span class="bold">Username: </span>admin</p>
	<p><span class="bold">Password: </span>password</p>

	<p>Once logged in, you will be able to edit the default company information with your own company details</p>

	<p>If you visit the 'Users' section of the Settings area, you will be able to add and remove new users.</p>

	<p><span class="bold">Note: </span>For obvious security reasons, the default admin user that is created in this installation process should ALWAYS be deleted once you have set up your own personal user account.</p>

</div>

<!-- // END STEP 3 -->


<?php else: ?>

	<p><span class="bold">Error:</span> Setup Has Already Been Completed On This Installation. For Security Reasons, Setup Has Now Been Disabled.</p>

	<p>If you need to run setup again, please consult your Adaptive Client Manager documentation for assistance.</p>

<?php endif; ?>	


<!-- INFO TILE -->

<?php

	$this->start('info_tile');

	$this->end();

?>
	


<!-- // END INFO TILE -->



<!-- SCRIPTS -->

<script type="text/javascript">

	$(document).ready(function() {

		prettyPrint();

		// Save Database Connection Details

		$('#test_connection_button').click(function() {
			$('#SetupIndexForm').submit();
		});


		// Hide Forms By Default

		$('.report_form').hide();


		// Show Forms On Click

		$('.show_hide_button').click(function() {

			$('.report_form').slideUp();

			$(this).next('div').slideToggle();

		});


	});

</script>




