<?php

	class InvoicesController extends AppController {

		public $uses = array('Invoice', 'Taxrates', 'Setting', 'EmailTemplate', 'Client');

		public $components = array('RequestHandler');

		public function beforeFilter() {
	        $this->set('title', 'invoices');

	        // Block Clients From Entire EmailTemplates Area & Redirect Them To Their Client Area
	        // Allow Clients Access To Invoices view()

	        $role = parent::roleCheck();
        	
        	if ($role === 'client') {

        		if ($this->action !== 'view') {

	        		$clientName = $this->Auth->user('first_name');

	        		$client = $this->Client->find('first', array(
	        			'conditions' => array('Client.client_name' => $clientName),
				        'fields' => array('id'),
					    'recursive' => 0
				    ));

	        		$this->Session->setFlash('Clients Are Only Authorised To View Their Own Area');

	        		$this->redirect(array('controller' => 'clients', 'action' => 'client_area', $client['Client']['id']));

	        	}

        	}
        	
	    }


	    function index() {

	        $this->set('invoices', $this->Invoice->find('all'));

	        $currency = $this->Setting->find('first', array(
		        'fields' => array('currency'),
			    'recursive' => 0
		    ));

		    $this->set('currency', $currency);

	    }


	    public function view($id = null) {
	        if (!$id) {
	            throw new NotFoundException(__('Invalid Invoice'));
	        }

	        $invoice = $this->Invoice->findById($id);

	        if (!$invoice) {
	            throw new NotFoundException(__('Invalid Invoice'));
	        }

	        // Block Clients From Accessing Other Client's Invoices

	        $role = parent::roleCheck();

	        if ($role === 'client') {

	        	if ($invoice['Invoice']['client_name'] !== AuthComponent::user('first_name')) {

	        		$this->Session->setFlash('Clients Are Only Authorised To View Their Own Area');

	        		$this->redirect(array('controller' => 'dashboard', 'action' => 'index'));

	        	}

	        }

	        $this->set('thisInvoice', $invoice);

	        $settings = $this->Setting->find('first');

	        $this->set('settings', $settings);

	    }


	    function add() {

	    	$lastInvoice = $this->Invoice->find('first', array(
		        'order' => array('Invoice.id' => 'desc'),
		        'fields' => array('Invoice.id'),
		        'recursive' => 0
		    ));

		    //print_r($lastInvoice) ;

		    if (!isset($lastInvoice['Invoice']['id'])) {

		    	$lastInvoice = 0;
		    }

	    	$this->set('lastInvoice', $lastInvoice);


	    	if ($this->request->is('post')) {

	            $this->Invoice->create();

	            if ($this->Invoice->save($this->request->data)) {

	                $this->Session->setFlash('Invoice Successfully Added');

	                $invoice_number = $this->request->data['Invoice']['invoice_number'];

	                $invoice = $this->Invoice->findByInvoiceNumber($invoice_number);

	                $invoice_id = $invoice['Invoice']['id'];

	                $this->redirect(array('controller' => 'invoices', 'action' => 'edit', $invoice_id));

	            } else {

	                $this->Session->setFlash('Unable To Add Invoice');

	            }

	        }

	    }


	    function edit($id = NULL) {

	        if (!$id) {

		        throw new NotFoundException(__('Invalid Invoice'));

		    }

		    $invoice = $this->Invoice->findById($id);

		    if (!$invoice) {

		        throw new NotFoundException(__('Invalid Invoice'));

		    }

		    $tax_rates = $this->Taxrates->find('list', array(

		    	'fields' => array('Taxrates.rate', 'Taxrates.rate'),
		    	'order' => array('Taxrates.rate' => 'asc')

		    	));

		    $this->set('tax_rates', $tax_rates);

		    $currency = $this->Setting->find('first', array(
		        'fields' => array('currency'),
			    'recursive' => 0
		    ));

		    $this->set('currency', $currency);

		    if ($this->request->is('post') || $this->request->is('put')) {

		        $this->Invoice->id = $id;

		        if ($this->Invoice->save($this->request->data)) {

		            $this->Session->setFlash('Your Invoice Has Been Updated');

		            $this->redirect(array('controller' => 'invoices', 'action' => 'edit', $id));

		        } else {

		            $this->Session->setFlash('Unable To Update Your Invoice');

		        }

		    }

		    if (!$this->request->data) {

		        $this->request->data = $invoice;

		    }

	    }


	    function delete($id) {

		    if ($this->request->is('get')) {

		        throw new MethodNotAllowedException('Access Denied Using This Method');

		    }

		    if ($this->Invoice->delete($id)) {

		        $this->Session->setFlash('The Invoice Has Been Deleted');

		        $this->redirect(array('action' => 'index'));

		    }
		}


		public function getRecent() {

			$recent = $this->Invoice->find('first');

			return $recent;

		}


		public function email($id = null) {
	        if (!$id) {
	            throw new NotFoundException(__('Invalid Invoice'));
	        }

	        $invoice = $this->Invoice->findById($id);

	        if (!$invoice) {
	            throw new NotFoundException(__('Invalid Invoice'));
	        }

	        $this->set('thisInvoice', $invoice);

	        $settings = $this->Setting->find('first');

	        $this->set('settings', $settings);

	        $template = $this->EmailTemplate->findByName('Client Invoice');

	        $this->set('template', $template);

	        App::import('Vendor', 'fpdf/tfpdf');

			// Set Vars

			$invoiceNumber = $invoice['Invoice']['invoice_number'];
			$invoiceDate = $invoice['Invoice']['invoice_date'];
			$invoiceNotes = $invoice['Invoice']['public_notes'];

			$currency = $settings['Setting']['currency'];

			$companyName = $settings['Setting']['company_name'];
			$companyAddress1 = $settings['Setting']['company_address_line_1'];
			$companyAddress2 = $settings['Setting']['company_address_line_2'];
			$companyTown = $settings['Setting']['company_town'];
			$companyCity = $settings['Setting']['company_city'];
			$companyState = $settings['Setting']['company_state'];
			$companyZip = $settings['Setting']['company_zip'];
			$companyPhone = $settings['Setting']['company_phone'];
			$companyEmail = $settings['Setting']['company_email'];
			$companyCustom = $settings['Setting']['custom_1'];
			$paymentInfo = $settings['Setting']['payment_info'];

			$companyFullAddress = '';

			if ($companyAddress1) {
			    $companyFullAddress = $companyFullAddress.$companyAddress1;
			}  

			if ($companyAddress2) {
			    $companyFullAddress = $companyFullAddress.', '.$companyAddress2;
			}

			if ($companyTown) {
			    $companyFullAddress = $companyFullAddress.', '.$companyTown;
			}

			if ($companyCity) {
			    $companyFullAddress = $companyFullAddress.', '.$companyCity;
			}

			if ($companyState) {
			    $companyFullAddress = $companyFullAddress.', '.$companyState;
			}

			if ($companyZip) {
			    $companyFullAddress = $companyFullAddress.', '.$companyZip;
			}

			if ($companyPhone) {
			    $companyFullAddress = $companyFullAddress.' | TEL: '.$companyPhone;
			}  

			if ($companyEmail) {
			    $companyFullAddress = $companyFullAddress.' | EMAIL: '.$companyEmail;
			} 

			if ($companyCustom) {
			    $companyFullAddress = $companyFullAddress.' | '.$companyCustom;
			} 


			$clientName = $invoice['Client']['client_name'];
			$clientAddress1 = $invoice['Client']['client_address_line_1'];
			$clientAddress2 = $invoice['Client']['client_address_line_2'];
			$clientTown = $invoice['Client']['client_town'];
			$clientCity = $invoice['Client']['client_city'];
			$clientState = $invoice['Client']['client_state'];
			$clientZip = $invoice['Client']['client_zip'];
			$clientPhone = $invoice['Client']['client_phone'];
			$clientEmail = $invoice['Client']['client_email'];
			$clientCustom = $invoice['Client']['custom_1'];


			$clientFullAddress = '';

			if ($clientAddress1) {
			    $clientFullAddress = $clientFullAddress.$clientAddress1;
			}  

			if ($clientAddress2) {
			    $clientFullAddress = $clientFullAddress.', '.$clientAddress2;
			}

			if ($clientTown) {
			    $clientFullAddress = $clientFullAddress.', '.$clientTown;
			}

			if ($clientCity) {
			    $clientFullAddress = $clientFullAddress.', '.$clientCity;
			}

			if ($clientState) {
			    $clientFullAddress = $clientFullAddress.', '.$clientState;
			}

			if ($clientZip) {
			    $clientFullAddress = $clientFullAddress.', '.$clientZip;
			}


			$clientContact = '';

			if ($clientPhone) {
			    $clientContact = 'TEL: '.$clientContact.$clientPhone.'    ';
			}  

			if ($clientEmail) {
			    $clientContact = $clientContact.'EMAIL: '.$clientEmail.'    ';
			}

			if ($clientCustom) {
			    $clientContact = $clientContact.$clientCustom;
			}


			$items = $invoice['Item'];

			$subTotal = 0;
			$tax = 0;
			$total = 0;


			// Create PDF

			$pdf = new tFPDF();
			$pdf->AddPage();
			$pdf->AddFont('Ostrich','','ostrich-regular-webfont.php');
			$pdf->AddFont('DejaVu','','DejaVuSansCondensed.ttf',true);

			$pdf->SetAutoPageBreak(true, 10);
			$pdf->SetDrawColor(238, 238, 238);
			$pdf->SetFillColor(238, 238, 238);
			$pdf->SetTextColor(80, 80, 80);


			// Company Logo

			$pdf->Image(IMAGES.'logo.png',10,10,88);


			// Invoice Details

			$pdf->setXY(180, 14);

			$pdf->SetFont('Ostrich','',40);
			$pdf->Cell(0, 4, 'INVOICE', 0, 2,'R');

			$pdf->SetFont('Ostrich','',26);
			$pdf->Cell(0, 16, '#'.$invoiceNumber, 0, 2,'R');

			$pdf->SetFont('DejaVu','',10);
			$pdf->Cell(0, 10, 'Date: '.$invoiceDate, 0, 1,'R');
			$pdf->Cell(0, 0, 'Due: '.$invoiceDate, 0, 1,'R');


			// Client Details

			$pdf->setXY(10, 38);

			$pdf->SetFont('DejaVu','',12);
			$pdf->Cell(0, 2, 'To: '.$clientName, 0, 2);
			
			$pdf->SetFont('DejaVu','',9);
			$pdf->Cell(0, 8, $clientFullAddress, 0, 2);

			$pdf->Cell(0, 0, $clientContact, 0, 2);

			$pdf->setXY(10, 58);


			// Invoice Items

			$pdf->SetFont('Ostrich','',14);
			$pdf->Cell(122, 10, 'Item', 0, 0);
			$pdf->Cell(16, 10, 'QTY', 0, 0, "C");
			$pdf->Cell(26, 10, 'Price', 0, 0, "R");
			$pdf->Cell(26, 10, 'Net SubTotal', 0, 1, "R");

			$pdf->SetFont('DejaVu','',9);

			foreach ($items as $item) {

				$itemSubTotal = $item['quantity'] * $item['unit_price'];

				$subTotal += $itemSubTotal;

				$itemTax = $itemSubTotal * ($item['tax_rate'] / 100);
				$tax += $itemTax;

				$itemSubTotal = number_format($itemSubTotal, 2, '.', ',');
				
				$pdf->SetTextColor(80, 80, 80);
				$pdf->SetFont('DejaVu','',9);
				$pdf->Cell(122, 6, $item['title'], 0, 0, "", true);
				$pdf->Cell(16, 6, $item['quantity'], 0, 0, "C", true);
				$pdf->Cell(26, 6, $item['unit_price'], 0, 0, "R", true);
				$pdf->Cell(26, 6, $itemSubTotal, 0, 1, "R", true);

				$pdf->SetTextColor(128, 128, 128);
				$pdf->SetFont('DejaVu','',9);
				$pdf->MultiCell(0, 5, $item['details'], 0, 2);

			}


			// Calculations & Totals

			$total = $subTotal + $tax;

			$total = number_format($total, 2, '.', ',');

			$tax = number_format($tax, 2, '.', ',');

			$subTotal = number_format($subTotal, 2, '.', ',');

			$pdf->setXY(10, 200);
			$pdf->SetFont('Ostrich','',16);
			$pdf->Cell(156, 10, 'Net Total:', 0, 2, "R");
			$pdf->setXY(10, 200);
			$pdf->SetFont('DejaVu','',16);
			$pdf->Cell(0, 10, $currency.$subTotal, 0, 2, "R");

			$pdf->setXY(10, 208);
			$pdf->SetFont('Ostrich','',16);
			$pdf->Cell(156, 10, 'Tax:', 0, 2, "R");
			$pdf->setXY(10, 208);
			$pdf->SetFont('DejaVu','',16);
			$pdf->Cell(0, 10, $currency.$tax, 0, 2, "R");

			$pdf->setXY(10, 218);
			$pdf->SetFont('Ostrich','',18);
			$pdf->Cell(156, 10, 'Total:', 0, 2, "R");
			$pdf->setXY(10, 218);
			$pdf->SetFont('DejaVu','',18);
			$pdf->Cell(0, 10, $currency.$total, 0, 2, "R");


			// Notes & Terms

			$pdf->setXY(10, 236);

			$pdf->SetTextColor(80, 80, 80);
			$pdf->SetFont('DejaVu','',9);

			$pdf->Cell(0, 6, 'Notes', 0, 2,'', true);

			$pdf->SetTextColor(128, 128, 128);
			$pdf->SetFont('DejaVu','',9);

			$pdf->MultiCell(0, 6, $invoiceNotes, 0, 2,'', true);

			$pdf->setXY(10, 256);

			$pdf->SetTextColor(80, 80, 80);
			$pdf->SetFont('DejaVu','',9);

			$pdf->Cell(0, 6, 'Payment Information', 0, 2,'', true);

			$pdf->SetTextColor(128, 128, 128);
			$pdf->SetFont('DejaVu','',9);
			
			$pdf->MultiCell(0, 6, $paymentInfo, 0, 2,'', true);

			
			// Footer - Company Details

			$pdf->setXY(0, 280);
			$pdf->SetTextColor(80, 80, 80);
			$pdf->SetFont('DejaVu','',7);

			$pdf->Cell(0, 4, $companyFullAddress, 0, 2,'C');

			$pdf->Output(WWW_ROOT.'/temp/Invoice_'.$invoiceNumber.'.pdf', 'F');

	    }


	    public function send() {

	        $id = $this->request->data['Invoice']['id'];
	        $invoiceNumber = $this->request->data['Invoice']['invoice_number'];
	        $to = $this->request->data['Invoice']['to'];
	        $from = $this->request->data['Invoice']['from'];
	        $message = $this->request->data['Invoice']['message'];

	        // print_r('ID: '.$id);
	        // print_r('Invoice: '.$invoiceNumber);
	        // print_r('To: '.$to);
	        // print_r('From: '.$from);
	        // print_r('Message: '.$message);

	        App::uses('CakeEmail', 'Network/Email');

			//$email = new CakeEmail('gmail');

			$email = new CakeEmail();

			$email->config(array(
				'from' => $from, 
				'transport' => 'Mail',
				'charset' => 'utf-8',
				'headerCharset' => 'utf-8'
				));


			$result = $email->emailFormat('html')
	            ->to($to)
	            ->from($from)
	            ->returnPath($from)
	            ->subject('New Invoice ('.$invoiceNumber.')')
	            ->attachments(WWW_ROOT.'/temp/Invoice_'.$invoiceNumber.'.pdf')
	            ->send($message);

	        //var_dump($result);

	        unlink(WWW_ROOT.'/temp/Invoice_'.$invoiceNumber.'.pdf');

	        $this->Session->setFlash('Email Sent');
	        $this->redirect(array('controller' => 'invoices', 'action' => 'view', $id));

	    }

	}

?>